<template>
  <a-card :bordered='false'>
    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form layout='inline' @keyup.enter.native='searchQuery'>
        <a-row :gutter='24'>
          <a-col :xl='6' :lg='7' :md='8' :sm='24' v-show='false'>
            <a-form-item label='批次'>
              <j-search-select-tag placeholder='请选择批次' v-model='queryParam.batchId' :dictOptions='batchOptions' />
            </a-form-item>
          </a-col>
          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <a-form-item label='产品型号'>
              <j-search-select-tag placeholder='请选择产品型号' v-model='queryParam.modelId' :dictOptions='modelOptions' />
            </a-form-item>
          </a-col>

          <template v-if='toggleSearchStatus'>

          </template>

          <a-col :xl='6' :lg='7' :md='8' :sm='24'>
            <span style='float: left;overflow: hidden;' class='table-page-search-submitButtons'>
              <a-button type='primary' @click='searchQuery' icon='search'>查询</a-button>
              <a-button type='primary' @click='searchReset' icon='reload' style='margin-left: 8px'>重置</a-button>
              <a @click='handleToggleSearch' style='margin-left: 8px'>
                {{ toggleSearchStatus ? '收起' : '展开' }}
                <a-icon :type="toggleSearchStatus ? 'up' : 'down'" />
              </a>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class='table-operator'>
      <a-button disabled @click='handleAdd' type='primary' icon='plus'>新增</a-button>
      <a-button type='primary' icon='download' @click="handleExportXls('lims_batch_sample')">导出</a-button>
      <a-upload name='file' :showUploadList='false' :multiple='false' :headers='tokenHeader' :action='importExcelUrl'
                @change='handleImportExcel'>
        <a-button disabled type='primary' icon='import'>导入</a-button>
      </a-upload>
      <!-- 高级查询区域 -->
      <j-super-query :fieldList='superFieldList' ref='superQueryModal'
                     @handleSuperQuery='handleSuperQuery'></j-super-query>
      <a-dropdown v-if='selectedRowKeys.length > 0'>
        <a-menu slot='overlay'>
          <a-menu-item key='1' @click='batchDel'>
            <a-icon type='delete' />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style='margin-left: 8px'> 批量操作
          <a-icon type='down' />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
      </div>

      <a-table
        ref='table'
        size='middle'
        :scroll='{x:true}'
        bordered
        rowKey='id'
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        class='j-table-force-nowrap'
        @change='handleTableChange'>

        <template slot='htmlSlot' slot-scope='text'>
          <div v-html='text'></div>
        </template>
        <template slot='imgSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无图片</span>
          <img v-else :src='getImgView(text)' height='25px' alt=''
               style='max-width:80px;font-size: 12px;font-style: italic;' />
        </template>
        <template slot='fileSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无文件</span>
          <a-button
            v-else
            :ghost='true'
            type='primary'
            icon='download'
            size='small'
            @click='downloadFile(text)'>
            下载
          </a-button>
        </template>

        <span slot='action' slot-scope='text, record'>
          <a @click='handleEdit(record)'>编辑</a>

          <a-divider type='vertical' />
          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
              <a-menu-item>
                <a @click='handleDetail(record)'>详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>

    <lims-batch-sample-modal ref='modalForm' @ok='modalFormOk'></lims-batch-sample-modal>
  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import LimsBatchSampleModal from './modules/LimsBatchSampleModal'
import { queryProModelList, queryBatchList } from '@api/lims'

export default {
  name: 'LimsBatchSampleList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    LimsBatchSampleModal
  },
  data() {
    return {
      description: 'lims_batch_sample管理页面',
      batchOptions: [],
      modelOptions: [],
      disableMixinCreated:true,
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '批次',
          align: 'center',
          dataIndex: 'batchName'
        },
        {
          title: '型号',
          align: 'center',
          dataIndex: 'modelName'
        },
        {
          title: '按型号编码',
          align: 'center',
          dataIndex: 'code'
        },
        {
          title: '通道号',
          align: 'center',
          dataIndex: 'channel'
        },
        {
          title: '判定结果',
          align: 'center',
          dataIndex: 'judgeResult'
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      isorter: {
        column: 'code',
        order: 'asc'
      },
      url: {
        list: '/lims/testing/sample/list',
        delete: '/lims/testing/sample/delete',
        deleteBatch: '/lims/testing/sample/deleteBatch',
        exportXlsUrl: '/lims/testing/sample/exportXls',
        importExcelUrl: '/lims/testing/sample/importExcel'

      },
      dictOptions: {},
      superFieldList: []
    }
  },
  created() {
    this.getSuperFieldList()
    if(!this.batch.id){
      this.$message.error("异常错误，请退出重试!")
      return false
    }
    this.queryParam.batchId = this.batch.id
    this.loadData()
    this.initDictConfig()
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    },
    batch() {
      return {
        id: this.$route.query.id,
        prodId: this.$route.query.prodId
      }
    }
  },
  methods: {
    searchReset() {
      this.queryParam = {}
      if(!this.batch.id){
        this.$message.error("异常错误，请退出重试!")
        return false
      }
      this.queryParam.batchId = this.batch.id
      this.loadData(1)
    },
    initDictConfig() {
      //产品型号列表
      queryProModelList({
        'prodId': this.batch.prodId == null ? 'empty' : this.batch.prodId,
        'pageNo': 1,
        'pageSize': 1000
      }).then(res => {
        if (res.success) {
          this.modelOptions = []
          res.result.records.forEach(item => {
            this.modelOptions.push({ 'text': item.modelName, 'value': item.id })
          })
        }
      })


      //产品型号列表
      queryBatchList({
        'id': this.batch.id == null ? 'empty' : this.batch.id,
        'pageNo': 1,
        'pageSize': 1000
      }).then(res => {
        console.info(res)
        if (res.success) {
          this.batchOptions = []
          res.result.records.forEach(item => {
            this.batchOptions.push({ 'text': item.batchCode, 'value': item.id })
          })
        }
      })
    },
    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'string', value: 'batchId', text: '批次' })
      fieldList.push({ type: 'string', value: 'modelId', text: '型号' })
      fieldList.push({ type: 'string', value: 'code', text: '按型号编码' })
      fieldList.push({ type: 'string', value: 'channel', text: '通道号' })
      fieldList.push({ type: 'string', value: 'judgeResult', text: '判定结果' })
      fieldList.push({ type: 'string', value: 'remark', text: '备注' })
      this.superFieldList = fieldList
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>